import { Observable } from 'rxjs';
import { AuthStateService } from './authState/auth-state.service';
import { CallbackService } from './callback/callback.service';
import { PeriodicallyTokenCheckService } from './callback/periodically-token-check.service';
import { RefreshSessionService } from './callback/refresh-session.service';
import { ConfigurationProvider } from './config/config.provider';
import { PublicConfiguration } from './config/public-configuration';
import { FlowsDataService } from './flows/flows-data.service';
import { CheckSessionService } from './iframe/check-session.service';
import { SilentRenewService } from './iframe/silent-renew.service';
import { LoggerService } from './logging/logger.service';
import { AuthOptions } from './login/auth-options';
import { LoginService } from './login/login.service';
import { LogoffRevocationService } from './logoffRevoke/logoff-revocation.service';
import { StoragePersistanceService } from './storage/storage-persistance.service';
import { UserService } from './userData/user-service';
import { TokenHelperService } from './utils/tokenHelper/oidc-token-helper.service';
export declare class OidcSecurityService {
    private readonly doc;
    private checkSessionService;
    private silentRenewService;
    private userService;
    private tokenHelperService;
    private loggerService;
    private configurationProvider;
    private authStateService;
    private flowsDataService;
    private callbackService;
    private logoffRevocationService;
    private loginService;
    private storagePersistanceService;
    private refreshSessionService;
    private periodicallyTokenCheckService;
    get configuration(): PublicConfiguration;
    get userData$(): Observable<any>;
    get isAuthenticated$(): Observable<boolean>;
    get checkSessionChanged$(): Observable<boolean>;
    get stsCallback$(): Observable<unknown>;
    constructor(doc: any, checkSessionService: CheckSessionService, silentRenewService: SilentRenewService, userService: UserService, tokenHelperService: TokenHelperService, loggerService: LoggerService, configurationProvider: ConfigurationProvider, authStateService: AuthStateService, flowsDataService: FlowsDataService, callbackService: CallbackService, logoffRevocationService: LogoffRevocationService, loginService: LoginService, storagePersistanceService: StoragePersistanceService, refreshSessionService: RefreshSessionService, periodicallyTokenCheckService: PeriodicallyTokenCheckService);
    checkAuth(url?: string): Observable<boolean>;
    checkAuthIncludingServer(): Observable<boolean>;
    private startCheckSessionAndValidation;
    getToken(): string;
    getIdToken(): string;
    getRefreshToken(): string;
    getPayloadFromIdToken(encode?: boolean): any;
    setState(state: string): void;
    getState(): string;
    authorize(authOptions?: AuthOptions): void;
    authorizeWithPopUp(authOptions?: AuthOptions): void;
    forceRefreshSession(): Observable<{
        idToken: string;
        accessToken: string;
    }>;
    logoffAndRevokeTokens(urlHandler?: (url: string) => any): Observable<any>;
    logoff(urlHandler?: (url: string) => any): void;
    logoffLocal(): void;
    revokeAccessToken(accessToken?: any): Observable<any>;
    revokeRefreshToken(refreshToken?: any): Observable<any>;
    getEndSessionUrl(): string | null;
}
